==> knative-model-5.2.0-sources.jar: io/fabric8/knative/serving/v1/ConfigurationSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationSpecFluentImpl<A extends ConfigurationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConfigurationSpecFluent<A> {

    private RevisionTemplateSpecBuilder template;

    public ConfigurationSpecFluentImpl() {
    }

    public ConfigurationSpecFluentImpl(ConfigurationSpec instance) {
        this.withTemplate(instance.getTemplate()); 
    }

    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public RevisionTemplateSpec getTemplate() {
        return this.template!=null?this.template.build():null;
    }

    public RevisionTemplateSpec buildTemplate() {
        return this.template!=null?this.template.build():null;
    }

    public A withTemplate(RevisionTemplateSpec template) {
        _visitables.get("template").remove(this.template);
        if (template!=null){ this.template= new RevisionTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
    }

    public Boolean hasTemplate() {
        return this.template != null;
    }

    public ConfigurationSpecFluent.TemplateNested<A> withNewTemplate() {
        return new TemplateNestedImpl();
    }

    public ConfigurationSpecFluent.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item) {
        return new TemplateNestedImpl(item);
    }

    public ConfigurationSpecFluent.TemplateNested<A> editTemplate() {
        return withNewTemplateLike(getTemplate());
    }

    public ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplate() {
        return withNewTemplateLike(getTemplate() != null ? getTemplate(): new RevisionTemplateSpecBuilder().build());
    }

    public ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item) {
        return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConfigurationSpecFluentImpl that = (ConfigurationSpecFluentImpl) o;
        if (template != null ? !template.equals(that.template) :that.template != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(template,  super.hashCode());
    }

    public class TemplateNestedImpl<N> extends RevisionTemplateSpecFluentImpl<ConfigurationSpecFluent.TemplateNested<N>> implements ConfigurationSpecFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RevisionTemplateSpecBuilder builder;

            TemplateNestedImpl(RevisionTemplateSpec item) {
                this.builder = new RevisionTemplateSpecBuilder(this, item);
                        
            }

            TemplateNestedImpl() {
                this.builder = new RevisionTemplateSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ConfigurationSpecFluentImpl.this.withTemplate(builder.build());
            }

            public N endTemplate() {
                return and();
            }
    }


}

==> knative-model-5.3.1-sources.jar: io/fabric8/knative/serving/v1/ConfigurationSpecFluentImpl.java <==
package io.fabric8.knative.serving.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConfigurationSpecFluentImpl<A extends ConfigurationSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConfigurationSpecFluent<A> {

    private RevisionTemplateSpecBuilder template;

    public ConfigurationSpecFluentImpl() {
    }

    public ConfigurationSpecFluentImpl(ConfigurationSpec instance) {
        this.withTemplate(instance.getTemplate()); 
    }

    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public RevisionTemplateSpec getTemplate() {
        return this.template!=null?this.template.build():null;
    }

    public RevisionTemplateSpec buildTemplate() {
        return this.template!=null?this.template.build():null;
    }

    public A withTemplate(RevisionTemplateSpec template) {
        _visitables.get("template").remove(this.template);
        if (template!=null){ this.template= new RevisionTemplateSpecBuilder(template); _visitables.get("template").add(this.template);} return (A) this;
    }

    public Boolean hasTemplate() {
        return this.template != null;
    }

    public io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<A> withNewTemplate() {
        return new TemplateNestedImpl();
    }

    public io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item) {
        return new TemplateNestedImpl(item);
    }

    public io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<A> editTemplate() {
        return withNewTemplateLike(getTemplate());
    }

    public io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplate() {
        return withNewTemplateLike(getTemplate() != null ? getTemplate(): new RevisionTemplateSpecBuilder().build());
    }

    public io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item) {
        return withNewTemplateLike(getTemplate() != null ? getTemplate(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConfigurationSpecFluentImpl that = (ConfigurationSpecFluentImpl) o;
        if (template != null ? !template.equals(that.template) :that.template != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(template,  super.hashCode());
    }

    public class TemplateNestedImpl<N> extends RevisionTemplateSpecFluentImpl<io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<N>> implements io.fabric8.knative.serving.v1.ConfigurationSpecFluent.TemplateNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final RevisionTemplateSpecBuilder builder;

            TemplateNestedImpl(RevisionTemplateSpec item) {
                this.builder = new RevisionTemplateSpecBuilder(this, item);
                        
            }

            TemplateNestedImpl() {
                this.builder = new RevisionTemplateSpecBuilder(this);
                        
            }

            public N and() {
                return (N) ConfigurationSpecFluentImpl.this.withTemplate(builder.build());
            }

            public N endTemplate() {
                return and();
            }
    }


}
